@@ -4,7 +4,7 @@
 
    Author: Ilan Schnell
 */
-#define BITARRAY_VERSION  "2.9.3"
+#define BITARRAY_VERSION  "3.0.0"
 
 #ifdef STDC_HEADERS
 #  include <stddef.h>
@@ -33,19 +33,6 @@
 #define Py_UNREACHABLE() abort()
 #endif
 
-#if PY_MAJOR_VERSION >= 3
-#define IS_PY3K  1
-#else
-#define IS_PY3K  0
-/* the Py_MIN and Py_MAX macros were introduced in Python 3.3 */
-#define Py_MIN(x, y)  (((x) > (y)) ? (y) : (x))
-#define Py_MAX(x, y)  (((x) > (y)) ? (x) : (y))
-#define PySlice_GetIndicesEx(slice, len, start, stop, step, slicelength) \
-    PySlice_GetIndicesEx(((PySliceObject *) slice),                      \
-                         (len), (start), (stop), (step), (slicelength))
-#define PyLong_FromLong  PyInt_FromLong
-#endif
-
 /* --- bitarrayobject --- */
 
 /* .ob_size is buffer size (in bytes), not the number of elements.
